@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.9   2013/02/14
+ * Version: 0.1.10   2013/05/12
  */
 
 #ifndef _SECURITY_CAITSITH_INTERNAL_H
@@ -47,6 +47,9 @@
 #include <linux/sysctl.h>
 #endif
 #include <linux/kthread.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 10, 0)
+#include <linux/magic.h>
+#endif
 #include <stdarg.h>
 #include <asm/uaccess.h>
 #include <net/sock.h>
@@ -882,8 +885,13 @@ void cs_warn_oom(const char *function);
 int cs_chroot_permission(struct path *path);
 int cs_chmod_permission(struct dentry *dentry, struct vfsmount *vfsmnt,
 			mode_t mode);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 5, 0)
+int cs_chown_permission(struct dentry *dentry, struct vfsmount *vfsmnt,
+			kuid_t user, kgid_t group);
+#else
 int cs_chown_permission(struct dentry *dentry, struct vfsmount *vfsmnt,
 			uid_t user, gid_t group);
+#endif
 int cs_fcntl_permission(struct file *file, unsigned int cmd,
 			unsigned long arg);
 int cs_ioctl_permission(struct file *filp, unsigned int cmd,
@@ -905,6 +913,7 @@ int cs_symlink_permission(struct dentry *dentry, struct vfsmount *mnt,
 int cs_truncate_permission(struct dentry *dentry, struct vfsmount *mnt);
 int cs_umount_permission(struct vfsmount *mnt, int flags);
 int cs_unlink_permission(struct dentry *dentry, struct vfsmount *mnt);
+int cs_socket_create_permission(int family, int type, int protocol);
 int cs_socket_bind_permission(struct socket *sock, struct sockaddr *addr,
 			      int addr_len);
 int cs_socket_connect_permission(struct socket *sock, struct sockaddr *addr,
