@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.9   2013/02/14
+ * Version: 0.1.10   2013/05/12
  */
 
 #include <linux/version.h>
@@ -24,13 +24,13 @@
 #include <linux/caitsith.h>
 
 /**
- * ccs_setup - Set enable/disable upon boot.
+ * cs_setup - Set enable/disable upon boot.
  *
  * @str: "off" to disable, "on" to enable.
  *
  * Returns 0.
  */
-static int __init ccs_setup(char *str)
+static int __init cs_setup(char *str)
 {
 	if (!strcmp(str, "off"))
 		caitsith_ops.disabled = 1;
@@ -39,79 +39,79 @@ static int __init ccs_setup(char *str)
 	return 0;
 }
 
-__setup("caitsith=", ccs_setup);
+__setup("caitsith=", cs_setup);
 
 #ifndef CONFIG_CAITSITH_OMIT_USERSPACE_LOADER
 
 /* Path to the policy loader. (default = CONFIG_CAITSITH_POLICY_LOADER) */
-static const char *ccs_loader;
+static const char *cs_loader;
 
 /**
- * ccs_loader_setup - Set policy loader.
+ * cs_loader_setup - Set policy loader.
  *
  * @str: Program to use as a policy loader (e.g. /sbin/caitsith-init ).
  *
  * Returns 0.
  */
-static int __init ccs_loader_setup(char *str)
+static int __init cs_loader_setup(char *str)
 {
-	ccs_loader = str;
+	cs_loader = str;
 	return 0;
 }
 
-__setup("CCS_loader=", ccs_loader_setup);
+__setup("CS_loader=", cs_loader_setup);
 
 /**
- * ccs_policy_loader_exists - Check whether /sbin/caitsith-init exists.
+ * cs_policy_loader_exists - Check whether /sbin/caitsith-init exists.
  *
  * Returns true if /sbin/caitsith-init exists, false otherwise.
  */
-static _Bool ccs_policy_loader_exists(void)
+static _Bool cs_policy_loader_exists(void)
 {
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 28)
 	struct path path;
-	if (!ccs_loader)
-		ccs_loader = CONFIG_CAITSITH_POLICY_LOADER;
-	if (kern_path(ccs_loader, LOOKUP_FOLLOW | LOOKUP_POSITIVE,
+	if (!cs_loader)
+		cs_loader = CONFIG_CAITSITH_POLICY_LOADER;
+	if (kern_path(cs_loader, LOOKUP_FOLLOW | LOOKUP_POSITIVE,
 		      &path) == 0) {
 		path_put(&path);
 		return 1;
 	}
 #else
 	struct nameidata nd;
-	if (!ccs_loader)
-		ccs_loader = CONFIG_CAITSITH_POLICY_LOADER;
-	if (path_lookup(ccs_loader, LOOKUP_FOLLOW | LOOKUP_POSITIVE,
+	if (!cs_loader)
+		cs_loader = CONFIG_CAITSITH_POLICY_LOADER;
+	if (path_lookup(cs_loader, LOOKUP_FOLLOW | LOOKUP_POSITIVE,
 			&nd) == 0) {
 		path_put(&nd.path);
 		return 1;
 	}
 #endif
 	printk(KERN_INFO "Not activating Mandatory Access Control "
-	       "as %s does not exist.\n", ccs_loader);
+	       "as %s does not exist.\n", cs_loader);
 	return 0;
 }
 
 /* Path to the trigger. (default = CONFIG_CAITSITH_ACTIVATION_TRIGGER) */
-static const char *ccs_trigger;
+static const char *cs_trigger;
 
 /**
- * ccs_trigger_setup - Set trigger for activation.
+ * cs_trigger_setup - Set trigger for activation.
  *
  * @str: Program to use as an activation trigger (e.g. /sbin/init ).
  *
  * Returns 0.
  */
-static int __init ccs_trigger_setup(char *str)
+static int __init cs_trigger_setup(char *str)
 {
-	ccs_trigger = str;
+	cs_trigger = str;
 	return 0;
 }
 
-__setup("CCS_trigger=", ccs_trigger_setup);
+__setup("CS_trigger=", cs_trigger_setup);
 
 /**
- * ccs_load_policy - Run external policy loader to load policy.
+ * cs_load_policy - Run external policy loader to load policy.
  *
  * @filename: The program about to start.
  *
@@ -123,24 +123,24 @@ __setup("CCS_trigger=", ccs_trigger_setup);
  * /sbin/caitsith-init reads policy files in /etc/caitsith/ directory and
  * writes to /proc/caitsith/ interfaces.
  */
-static void ccs_load_policy(const char *filename)
+static void cs_load_policy(const char *filename)
 {
 	static _Bool done;
 	if (caitsith_ops.disabled || done)
 		return;
-	if (!ccs_trigger)
-		ccs_trigger = CONFIG_CAITSITH_ACTIVATION_TRIGGER;
-	if (strcmp(filename, ccs_trigger))
+	if (!cs_trigger)
+		cs_trigger = CONFIG_CAITSITH_ACTIVATION_TRIGGER;
+	if (strcmp(filename, cs_trigger))
 		return;
-	if (!ccs_policy_loader_exists())
+	if (!cs_policy_loader_exists())
 		return;
 	done = 1;
 	{
 		char *argv[2];
 		char *envp[3];
 		printk(KERN_INFO "Calling %s to load policy. Please wait.\n",
-		       ccs_loader);
-		argv[0] = (char *) ccs_loader;
+		       cs_loader);
+		argv[0] = (char *) cs_loader;
 		argv[1] = NULL;
 		envp[0] = "HOME=/";
 		envp[1] = "PATH=/sbin:/bin:/usr/sbin:/usr/bin";
@@ -158,28 +158,27 @@ static void ccs_load_policy(const char *filename)
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 8, 0)
 
 /**
- * __ccs_search_binary_handler - Load policy before calling search_binary_handler().
+ * cs_search_binary_handler - Load policy before calling search_binary_handler().
  *
  * @bprm: Pointer to "struct linux_binprm".
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int __ccs_search_binary_handler(struct linux_binprm *bprm)
+static int cs_search_binary_handler(struct linux_binprm *bprm)
 {
 #ifndef CONFIG_CAITSITH_OMIT_USERSPACE_LOADER
-	ccs_load_policy(bprm->filename);
+	cs_load_policy(bprm->filename);
 #endif
 	/*
-	 * ccs_load_policy() executes /sbin/caitsith-init if bprm->filename is
+	 * cs_load_policy() executes /sbin/caitsith-init if bprm->filename is
 	 * /sbin/init. /sbin/caitsith-init executes
 	 * /etc/caitsith/caitsith-load-module to load loadable kernel module.
 	 * The loadable kernel module modifies "struct caitsith_ops". Thus,
-	 * we need to transfer control to __ccs_search_binary_handler() in
+	 * we need to transfer control to cs_search_binary_handler() in
 	 * security/caitsith/permission.c if "struct caitsith_ops" was
 	 * modified.
 	 */
-	if (caitsith_ops.search_binary_handler
-	    != __ccs_search_binary_handler)
+	if (caitsith_ops.search_binary_handler != cs_search_binary_handler)
 		return caitsith_ops.search_binary_handler(bprm);
 	return search_binary_handler(bprm);
 }
@@ -187,30 +186,29 @@ static int __ccs_search_binary_handler(struct linux_binprm *bprm)
 #else
 
 /**
- * __ccs_search_binary_handler - Load policy before calling search_binary_handler().
+ * cs_search_binary_handler - Load policy before calling search_binary_handler().
  *
  * @bprm: Pointer to "struct linux_binprm".
  * @regs: Pointer to "struct pt_regs".
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int __ccs_search_binary_handler(struct linux_binprm *bprm,
-				       struct pt_regs *regs)
+static int cs_search_binary_handler(struct linux_binprm *bprm,
+				    struct pt_regs *regs)
 {
 #ifndef CONFIG_CAITSITH_OMIT_USERSPACE_LOADER
-	ccs_load_policy(bprm->filename);
+	cs_load_policy(bprm->filename);
 #endif
 	/*
-	 * ccs_load_policy() executes /sbin/caitsith-init if bprm->filename is
+	 * cs_load_policy() executes /sbin/caitsith-init if bprm->filename is
 	 * /sbin/init. /sbin/caitsith-init executes
 	 * /etc/caitsith/caitsith-load-module to load loadable kernel module.
 	 * The loadable kernel module modifies "struct caitsith_ops". Thus,
-	 * we need to transfer control to __ccs_search_binary_handler() in
+	 * we need to transfer control to cs_search_binary_handler() in
 	 * security/caitsith/permission.c if "struct caitsith_ops" was
 	 * modified.
 	 */
-	if (caitsith_ops.search_binary_handler
-	    != __ccs_search_binary_handler)
+	if (caitsith_ops.search_binary_handler != cs_search_binary_handler)
 		return caitsith_ops.search_binary_handler(bprm, regs);
 	return search_binary_handler(bprm, regs);
 }
@@ -231,7 +229,7 @@ extern spinlock_t vfsmount_lock;
 /* For exporting variables and functions. */
 const struct caitsith_exports caitsith_exports = {
 #ifndef CONFIG_CAITSITH_OMIT_USERSPACE_LOADER
-	.load_policy = ccs_load_policy,
+	.load_policy = cs_load_policy,
 #endif
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 2, 0)
 	.d_absolute_path = d_absolute_path,
@@ -250,7 +248,7 @@ EXPORT_SYMBOL_GPL(caitsith_exports);
 
 /* Members are updated by loadable kernel module. */
 struct caitsith_operations caitsith_ops = {
-	.search_binary_handler = __ccs_search_binary_handler,
+	.search_binary_handler = cs_search_binary_handler,
 #ifdef CONFIG_CAITSITH_DISABLE_BY_DEFAULT
 	.disabled = 1,
 #endif
